@@ -70,9 +70,13 @@ typedef signed long long   i64;
 #else // HAVE_CONFIG_H
 
 typedef   unsigned char        u8;
+typedef   signed char          i8;
 typedef   unsigned short       u16;
+typedef   signed short         i16;
 typedef   unsigned int         u32;
+typedef   signed int           i32;
 typedef   unsigned long long   u64;
+typedef   signed long long     i64;
 
 #endif
 #endif
