@@ -40,17 +40,16 @@ public:
   ~Par2CreatorSourceFile(void);
 
   // Open the source file and compute the Hashes and CRCs.
-  //bool Open(NoiseLevel noiselevel, const string &extrafile, u64 blocksize, bool deferhashcomputation, string basepath);
 #ifdef _OPENMP
-  bool Open(NoiseLevel noiselevel, std::ostream &sout, std::ostream &serr, const string &extrafile, u64 blocksize, bool deferhashcomputation, string basepath, u64 totalsize, u64 &totalprogress);
+  bool Open(NoiseLevel noiselevel, std::ostream &sout, std::ostream &serr, const std::string &extrafile, u64 blocksize, bool deferhashcomputation, std::string basepath, u64 totalsize, u64 &totalprogress);
 #else
-  bool Open(NoiseLevel noiselevel, std::ostream &sout, std::ostream &serr, const string &extrafile, u64 blocksize, bool deferhashcomputation, string basepath);
+  bool Open(NoiseLevel noiselevel, std::ostream &sout, std::ostream &serr, const std::string &extrafile, u64 blocksize, bool deferhashcomputation, std::string basepath);
 #endif
   void Close(void);
 
   // Recover the file description and file verification packets
   // in the critical packet list.
-  void RecordCriticalPackets(list<CriticalPacket*> &criticalpackets);
+  void RecordCriticalPackets(std::list<CriticalPacket*> &criticalpackets);
 
   // Get the file id
   const MD5Hash& FileId(void) const;
@@ -59,7 +58,7 @@ public:
   static bool CompareLess(const Par2CreatorSourceFile* const &left, const Par2CreatorSourceFile* const &right);
 
   // Allocate the appropriate number of source blocks to the source file
-  void InitialiseSourceBlocks(vector<DataBlock>::iterator &sourceblock, u64 blocksize);
+  void InitialiseSourceBlocks(std::vector<DataBlock>::iterator &sourceblock, u64 blocksize);
 
   // Update the file hash and the block crc and hashes
   void UpdateHashes(u32 blocknumber, const void *buffer, size_t length);
@@ -76,8 +75,8 @@ protected:
   DiskFile           *diskfile;           // The source file
 
   u64    filesize;      // The size of the source file.
-  string diskfilename;  // The filename of the source file on disk.
-  string parfilename;   // The filename that will be recorded in the file description packet.
+  std::string diskfilename;  // The filename of the source file on disk.
+  std::string parfilename;   // The filename that will be recorded in the file description packet.
 
   u32    blockcount;    // How many blocks the file will be divided into.
 
